@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: dlist-instances
 version: 0.1
-id: dlist-instances-0.1-235f738d61a8b9c3c8305b99c3fa9cbe
-key: dlist_2sRiQgXaNZHKQitnxPQgSF
+id: dlist-instances-0.1-cab5ba8dec85a2fc711ad48fe3f632f9
+key: dlist_6isURnHSCcfIvnfJMWq0Dl
 license: BSD3
 copyright: 2013 Greg Weber
 maintainer: Greg Weber <greg@gregweber.info>
@@ -22,11 +22,11 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/dlist-instances-0.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/dlist-instances-0.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/dlist-instances-0.1
-hs-libraries: HSdlist-instances-0.1-2sRiQgXaNZHKQitnxPQgSF
+hs-libraries: HSdlist-instances-0.1-6isURnHSCcfIvnfJMWq0Dl
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     dlist-0.7.1.2-60b8202d1ee1445c0a53e803464ea95b
-    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
+    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
 haddock-interfaces: /usr/share/doc/haskell-dlist-instances/html/dlist-instances.haddock
 haddock-html: /usr/share/doc/haskell-dlist-instances/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
